@@ -259,8 +259,6 @@ eel_gtk_window_set_initial_geometry (GtkWindow *window,
 	int screen_width, screen_height;
 
 	g_return_if_fail (GTK_IS_WINDOW (window));
-	g_return_if_fail (!(geometry_flags & EEL_GDK_WIDTH_VALUE));
-	g_return_if_fail (!(geometry_flags & EEL_GDK_HEIGHT_VALUE));
 
 	/* Setting the default size doesn't work when the window is already showing.
 	 * Someday we could make this move an already-showing window, but we don't
