@@ -35,7 +35,6 @@
 #include <pango/pango-attributes.h>
 #include <pango/pango-break.h>
 #include <pango/pango-context.h>
-#include <pango/pangoft2.h>
 #include <string.h>
 
 PangoAttrList *
@@ -550,21 +549,6 @@ eel_pango_font_description_get_largest_fitting_font_size (const PangoFontDescrip
 }
 
 
-PangoContext *
-eel_pango_ft2_get_context (void)
-{
-	PangoContext *context;
-	double dpi_x, dpi_y;
-			
-	dpi_x = gdk_screen_width () * 25.4 / gdk_screen_width_mm ();
-	dpi_y = gdk_screen_height () * 25.4 / gdk_screen_height_mm ();
-	context = pango_ft2_get_context (dpi_x, dpi_y);
-
-	pango_context_set_language (context, gtk_get_default_language ());
-
-	return context;
-}
-
 #if !defined (EEL_OMIT_SELF_CHECK)
 
 static PangoContext *
